/**
 * @file ip_check.h
 *
 * @brief this file is the header file of ip conflict checking tool
 *
 * @author yanghao <yanghao@kylinos.cn>
 *
 * @version 1.0.0
 *
 */

#ifndef IP_CHECK_H
#define IP_CHECK_H

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <stdint.h>
#include <regex.h>

#include <unistd.h>
#include <time.h>
#include <errno.h>
#include <sys/time.h>
#include <sys/ioctl.h>
#include <sys/socket.h>
#include <sys/poll.h>
#include <sys/types.h>
#include <net/if.h>
#include <net/if_arp.h>  
#include <netinet/in.h>
#include <netinet/if_ether.h>   
#include <ifaddrs.h>
#include <arpa/inet.h>

#include <libnotify/notify.h>
#include <libnotify/notification.h>

/**
 * @brief get_first_interface 获取当前激活的网卡接口名称
 * @return 返回当前激活的网卡接口名称
 */
//char *get_first_interface(void);

/**
 * @brief get_interface_info    获取指定网络接口信息
 * @param interface     网络接口
 * @param if_hw_addr    要获取的MAC地址
 * @param if_ip_addr    要获取的IP地址
 * @return 成功，返回（获取到MAC（1）+获取到IP（2））；失败，返回-1
 */
int get_interface_info(char *interface, uint8_t *if_hw_addr,
                       struct in_addr* if_ip_addr);

/**
 * @brief  ip_check 检测IP地址是否可用
 * @param interface 网卡接口
 * @param dest_ip   要检测的IP地址
 * @param dest_mac  如果IP被占用，返回该IP所属MAC地址
 * @return 返回检测结果 IP被占用，返回1；IP闲置，返回0；失败，返回-1
 */
extern int ip_check(char* interface, struct in_addr *dest_ip, uint8_t *dest_mac);

/**
 * @brief ipcheck_result    转换IP检测结果
 * @param ret       检测结果
 * @param dest_mac  检测到的IP所属MAC地址
 * @return  返回结果表示字符串
 */
const char* ipcheck_result(int ret, struct in_addr dest_ip, uint8_t *dest_mac);

/**
 * @brief send_result_to_notify 发送检测结果到通知
 * @param ret       检测结果
 * @param dest_mac  检测到的IP所属MAC地址
 */
void send_result_to_notify(int ret, struct in_addr dest_ip, uint8_t *dest_mac);

/**
 * @brief ip_verify 验证IP字符串是否是合法IP
 * @param ip 要验证的ip
 * @return 是，返回1；否，返回0
 */
extern int ip_verify(const char *ip);

 
#endif
  
